package test;

import java.awt.BorderLayout;
import java.awt.FlowLayout;

import javax.swing.*;

import org.jvnet.substance.SubstanceLookAndFeel;
import org.jvnet.substance.skin.SubstanceBusinessBlackSteelLookAndFeel;

public class Menu extends JFrame {
	public Menu() {
		super("Some simple text");
		this.setLayout(new BorderLayout());

		JMenuBar jmb = new JMenuBar();
		JMenu menu1 = new JMenu("menu1");
		JMenu submenu = new JMenu("Submenu");
		submenu.add(new JMenuItem("submenuitem 111"));
		// menu1.add(submenu);
		menu1.add(new JCheckBoxMenuItem("Submenu"));
		jmb.add(menu1);
		this.setJMenuBar(jmb);

		this.setLayout(new FlowLayout());
		this.add(new JButton("text", Check.getIcon("flag_sweden")));

		this.setSize(300, 200);
		this.setLocationRelativeTo(null);
		this.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
	}

	public static void main(String[] args) throws Exception {
		UIManager.setLookAndFeel(new SubstanceBusinessBlackSteelLookAndFeel());
		// UIManager.put(LafWidget.ANIMATION_KIND, AnimationKind.DEBUG);
		UIManager.put(SubstanceLookAndFeel.USE_THEMED_DEFAULT_ICONS,
				Boolean.TRUE);
		JFrame.setDefaultLookAndFeelDecorated(true);
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				new Menu().setVisible(true);
			}
		});
	}
}
